# icenet

This is the core python library for the IceNet project. 

## Usage

### Installation

We're still working on clear dependency management using pip, Tensorflow is best through pip but obviously you need NVIDIA dependencies for GPU based training. If you're having trouble with system dependencies some advice about environment setup is given by the examples [under the pipeline repository][1].

```
pip install icenet
```

## License

This is licensed using the [MIT License](LICENSE)

[1]: https://github.com/icenet-ai/icenet-pipeline
